;;-----------------------------LICENSE NOTICE------------------------------------
;; This file is part of Invasion a Marte: An Amstrad CPC Game 
;; Copyright (C) 2019 
;; Authors:
;;  * Antonio Macia Lillo       tonetml23@gmail.com
;;  * Gina Esthela Abad Jimenez abadjimenezgina@gmail.com
;;  * Ivan Martinez Molina      imm79@alu.ua.es
;;
;;  This program is free software: you can redistribute it and/or modify
;;  it under the terms of the GNU Lesser General Public License as published by
;;  the Free Software Foundation, either version 3 of the License, or
;;  (at your option) any later version.
;;
;;  This program is distributed in the hope that it will be useful,
;;  but WITHOUT ANY WARRANTY; without even the implied warranty of
;;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;  GNU Lesser General Public License for more details.
;;
;;  You should have received a copy of the GNU Lesser General Public License
;;  along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;-------------------------------------------------------------------------------

.include "sys/collision_system.h.s"
.include "man/entity_manager.h.s"
.include "cpctelera.h.s"
.include "player_manager.h.s"

outer_counter: .db 00
coll_handler: .dw 0x0000

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Does nothing at the moment
;;
;;INPUT:
;; 
;;DESTROYS: 
;;
man_collision_init::
    ret

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Checks collisions between collisionable objects
;;
;;INPUT:
;; IX: Pointer to collision array
;; A: Number of collision pointers
;; 
;;DESTROYS: 
;; IX, A, IY, BC, DE
;;
man_collision_update::
_outer_loop:
    ld__d_ixh                           ;; IX: Pointer to the first object
    ld__e_ixl

    ld__iyh_d                           ;; IY: Pointer to the second object
    ld__iyl_e

    ld (outer_counter), a               ;; Save counter value

_inner_loop:
    dec a
    jp z, _update_outer_counters
    ld bc, #sizeof_c                    ;; Load size of pointer to bc
    add iy, bc                          ;; Point to the next object

    push ix
    push iy
    push af
    ;;Load actual pointers to the object
    ld e, 0(ix)
    ld d, 1(ix)
    ld__ixh_d
    ld__ixl_e
    ld e, 0(iy)
    ld d, 1(iy)
    ld__iyh_d
    ld__iyl_e
    call collision_check                ;; Check collision between ix and iy
    call z, collision_happens           ;; If collision happens, aply action
    pop af
    pop iy
    pop ix
                             ;; inner counter --
    jp _inner_loop

_update_outer_counters:
    ld bc, #sizeof_c                    ;; Load size of pointer to bc
    add ix, bc                          ;; Point to the next object

    ld a, (outer_counter)
    dec a                               ;; outer_counter--
    jp nz, _outer_loop

    ret


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Aplies the consecuences of a collision bassed on the type of collision object
;;
;;INPUT:
;; IX: Pointer to entity 1
;; IY: Pointer to entity 2
;; 
;;DESTROYS: 
;; IX, AF, IY, BC, DE, HL
;;
collision_happens:
    ;; NOTE: Handlers allways expect the object to be in IX
    ;; First object action
    ld hl, #_first_obj_end                  ;; Load onto the stack the return direction
    push hl
    ld l,  e_collision_handler_l(ix)        ;; Load memory location to jump for the handler
    ld h, e_collision_handler_h(ix)
    jp (hl) 
                                    ;; Jump to the handler
_first_obj_end:
    ;; Second object action
    ld__d_iyh                               ;; Load iy pointer to hl
    ld__e_iyl
    ld__b_ixh
    ld__c_ixl

    ld__ixh_d                               ;; Load iy onto ix
    ld__ixl_e
    ld__iyh_b                               ;; Load ix onto iy
    ld__iyl_c
    ld hl, #no_handler                      ;; Load onto the stack the return direction
    push hl
    ld l,  e_collision_handler_l(ix)        ;; Load memory location to jump for the handler
    ld h, e_collision_handler_h(ix)
    jp (hl)                                 ;; Jump to the handler
no_handler::                                ;; Memory direction if nothin has to be done
    ret


;;ALL HANDLERS EXPECT ON IY THE OTHER OBJECT
player_collides::
    ld a, e_collider(iy)                    ;; Get objetc type onto a
    cp a, #coll_type_bullet                 ;; If its bullet shot from the player do no
    jp z, _player_pop_ret                   ;; Jump if it is
    call man_player_hit
_player_pop_ret:    
    pop hl                                  ;; Pop the jump direction from the stack
    jp (hl)                                 ;; Go back to where the call was made

bullet_collides::
    ld a, e_collider(iy)                    ;; Get objetc type onto a
    cp a, #coll_type_player                 ;; If its bullet shot from the player do no
    jp z, _bullet_pop_ret                   ;; Jump if it is

    ld__d_ixh
    ld__e_ixl
    push ix
    call entityman_deletearr_add
    pop ix
_bullet_pop_ret:    
    pop hl                                  ;; Pop the jump direction from the stack
    jp (hl)                                 ;; Go back to where the call was made

enemy_collides::
    ld__d_ixh                               ;; Pass ix to de for the input of the 
    ld__e_ixl                               ;; function
    
    ld a, e_collider(iy)
    cp a, #coll_type_enemy_bullet
    jp z, #_ec_dont_delete
    cp a, #coll_type_enemy
    push ix
    call nz, entityman_deletearr_add
    pop ix
_ec_dont_delete:
    
    pop hl                                  ;; Pop the jump direction from the stack
    jp (hl)                                 ;; Go back to where the call was made

notihng_collides::
    pop hl                                  ;; Pop the jump direction from the stack
    jp (hl)                                 ;; Go back to where the call was made