;;-----------------------------LICENSE NOTICE------------------------------------
;; This file is part of Invasion a Marte: An Amstrad CPC Game 
;; Copyright (C) 2019 
;; Authors:
;;  * Antonio Macia Lillo       tonetml23@gmail.com
;;  * Gina Esthela Abad Jimenez abadjimenezgina@gmail.com
;;  * Ivan Martinez Molina      imm79@alu.ua.es
;;
;;  This program is free software: you can redistribute it and/or modify
;;  it under the terms of the GNU Lesser General Public License as published by
;;  the Free Software Foundation, either version 3 of the License, or
;;  (at your option) any later version.
;;
;;  This program is distributed in the hope that it will be useful,
;;  but WITHOUT ANY WARRANTY; without even the implied warranty of
;;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;  GNU Lesser General Public License for more details.
;;
;;  You should have received a copy of the GNU Lesser General Public License
;;  along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;-------------------------------------------------------------------------------

.include "man/game_manager.h.s"
.include "man/player_manager.h.s"
.include "man/entity_manager.h.s"
.include "assets/sprites.h.s"
.include "sys/render_system.h.s"

DefineEntity bullet, 0, 0, 2, 4, 0, 0, 0xF0, coll_type_bullet, 1, 0x0000, #e_ai_st_noAI, _sp_bala, 0x0000, 0x0000, action_enemy_patrol
;DefineEntity bullet, 0, 0, 2, 4, 0, 0, 0xF0, coll_type_bullet, 1, 0x0000, #e_ai_st_noAI, _sp_bala
;DefineEntity bullet, 0, 0, 1, 1, 0, 0, 0xF0, coll_type_bullet, 1, 0x0000, #e_ai_st_noAI, _sp_bala1

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Aplies the penalty of being hit
;;
;;INPUT: -
;;DESTROYS: A
;;
man_player_init::
    ;;Load health initial value
    ld a, #3
    ld (health), a

    ld a, #0
    ld (shootfw_cicle_timer), a
    ld (hit_cicle_timer), a


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Aplies the penalty of being hit
;;
;;INPUT: -
;;DESTROYS: A, HL
;;
man_player_update::
    ;;Check if counter is already 0
    ld a, (hit_cicle_timer)
    and a
    jp z, _end_hit_dec                  ;; If cicle timer is not 0, do nothing
    dec a                               ;; clicle_timer--
    ld (hit_cicle_timer), a             ;; Store its value in memory

    ;;Make player blink
    push af
    call entityman_getEntityArray
    pop af
    bit 0, a                             ;; Alternate between 0 and 1
    jp nz, _end_hit_dec
    bit 1, a
    jp nz, _end_hit_dec

    ld hl, #_sp_elemento2_15
    ld e_pspr_h(ix), h
    ld e_pspr_l(ix), l

_end_hit_dec:
    ld a, (shootfw_cicle_timer)
    and a
    jp z, _end_man_update               ;; If cicle timer is not 0, do nothing
    dec a                               ;; clicle_timer--
    ld (shootfw_cicle_timer), a                 ;; Store its value in memory

    

_end_man_update:
    ret
    

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  SYS AI CONTROL::update
;;      Updates all AI entities
;;
;;  INPUT:
;;      IX: Pointer to entity array
;;      A: Number of elements in the array
;;  DESTROYS: AF, DE, BC, IX
;;  STACK USE: 2 bytes;;
;;DESCRIPTION
;; Gets the status values for the player. That is,
;; the health.
;;
;;INPUT: -
;;DESTROYS: AF, BC, DE, HL
;;RETURNS:
;; B: Health
;; A: Health
;;
man_player_getdata::
    ld a, (health)                      ;; Load health value to a
    ld b, a                             ;; Load health value to b
    ret

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Aplies the penalty of being hit
;;
;;INPUT: -
;;DESTROYS: A
;;
man_player_hit::
    ;;Check if was hit recently (invicibility after hit)
    ld a, (hit_cicle_timer)
    and a                               ;; Set flags acordingly to a value
    jp nz, _health_not_cero             ;; If cicle timer is not 0, do nothing

    ;;Set cicle_timer.
    ld a, #wait_cicles                  ;; Load cicles to wait in a
    ld (hit_cicle_timer), a                 ;; Set the value to the cicle_timer memory

    ;;Decrease and check life value
    ld a, (health)                      ;; Load current health value in a
    dec a
    ld (health), a

    jp nz, _health_not_cero             ;; If health == 0, gameover
    call man_game_set_gameover
_health_not_cero:
        ;;set life intf
    ld a, (health)  
    cp #2
    jp nz, _not_two
    ld hl, #_sp_elemento2_15
    ld (life3), hl
    jp _not_one
_not_two:
    ld hl, #_sp_elemento2_15
    ld (life2), hl

_not_one:

    ret


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Makes the player shoot forward
;;
;;INPUT: -entityman_getEntityArray
;;DESTROYS: AF, IX
;;ASSUMES PLAYER IS AT POSSITION 0
man_player_shoot_forward::
    ;;Check if it shoot (cooldown time)
    ld a, (shootfw_cicle_timer)
    and a                               ;; Set flags acordingly to a value
    jp nz, _end_shoot_fw                ;; If cicle timer is not 0, do nothing

    ;;Set cicle_timer.
    ld a, #wait_cicles_shoot                  ;; Load cicles to wait in a
    ld (shootfw_cicle_timer), a                 ;; Set the value to the cicle_timer memory

    call entityman_getEntityArray           ;;Get entity array on IX
    ld iy, #bullet                          ;;Get bullet entity in IY

    ;;update x and y values of the bullet
    ld d, e_x(ix)                           ;;Get player x possition (Bullet starts at player possition)
    ld a, #5
    add d
    ld d, a

    ld e, e_y(ix)                           ;;Get player y possition
    ld e_x(iy), d
    ld e_y(iy), e

    ;;update speed x and y of the bullet
    ld e_vx(iy), #0
    ld e_vy(iy), #-3
    
    ;;Add bullet to entity array
    ld hl, #bullet
    call entityman_create

_end_shoot_fw:
    ret


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Makes the player shoot left
;;
;;INPUT: -entityman_getEntityArray
;;DESTROYS: AF, IX
;;ASSUMES PLAYER IS AT POSSITION 0
man_player_shoot_left::
    ;;Check if it shoot (cooldown time)
    ld a, (shootfw_cicle_timer)
    and a                               ;; Set flags acordingly to a value
    jp nz, _end_shoot_lft                ;; If cicle timer is not 0, do nothing

    ;;Set cicle_timer.
    ld a, #wait_cicles_shoot                  ;; Load cicles to wait in a
    ld (shootfw_cicle_timer), a                 ;; Set the value to the cicle_timer memory

    call entityman_getEntityArray           ;;Get entity array on IX
    ld iy, #bullet                          ;;Get bullet entity in IY

    ;;update x and y values of the bullet
    ld d, e_x(ix)                           ;;Get player x possition (Bullet starts at player possition)
    ld a, #5
    add d
    ld d, a
    ld e, e_y(ix)                           ;;Get player y possition
    ld e_x(iy), d
    ld e_y(iy), e

    ;;update speed x and y of the bullet
    ld e_vx(iy), #-1
    ld e_vy(iy), #-3
    
    ;;Add bullet to entity array
    ld hl, #bullet
    call entityman_create

_end_shoot_lft:
    ret


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Makes the player shoot right
;;
;;INPUT: -entityman_getEntityArray
;;DESTROYS: AF, IX
;;ASSUMES PLAYER IS AT POSSITION 0
man_player_shoot_right::
    ;;Check if it shoot (cooldown time)
    ld a, (shootfw_cicle_timer)
    and a                               ;; Set flags acordingly to a value
    jp nz, _end_shoot_rgt                ;; If cicle timer is not 0, do nothing

    ;;Set cicle_timer.
    ld a, #wait_cicles_shoot                  ;; Load cicles to wait in a
    ld (shootfw_cicle_timer), a                 ;; Set the value to the cicle_timer memory

    call entityman_getEntityArray           ;;Get entity array on IX
    ld iy, #bullet                          ;;Get bullet entity in IY

    ;;update x and y values of the bullet
    ld d, e_x(ix)                           ;;Get player x possition (Bullet starts at player possition)
    ld e, e_y(ix)                           ;;Get player y possition
    ld a, #5
    add d
    ld d, a
    ld e_x(iy), d
    ld e_y(iy), e

    ;;update speed x and y of the bullet
    ld e_vx(iy), #1
    ld e_vy(iy), #-3
    
    ;;Add bullet to entity array
    ld hl, #bullet
    call entityman_create

_end_shoot_rgt:
    ret