;;-----------------------------LICENSE NOTICE------------------------------------
;; This file is part of Invasion a Marte: An Amstrad CPC Game 
;; Copyright (C) 2019 
;; Authors:
;;  * Antonio Macia Lillo		tonetml23@gmail.com
;;  * Gina Esthela Abad Jimenez	abadjimenezgina@gmail.com
;;  * Ivan Martinez Molina		imm79@alu.ua.es
;;
;;  This program is free software: you can redistribute it and/or modify
;;  it under the terms of the GNU Lesser General Public License as published by
;;  the Free Software Foundation, either version 3 of the License, or
;;  (at your option) any later version.
;;
;;  This program is distributed in the hope that it will be useful,
;;  but WITHOUT ANY WARRANTY; without even the implied warranty of
;;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;  GNU Lesser General Public License for more details.
;;
;;  You should have received a copy of the GNU Lesser General Public License
;;  along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;-------------------------------------------------------------------------------

;;
;; ENTITY AI CONTROL SYSTEM
;;

.include "man/entity_manager.h.s"
.include "man/patrol_manager.h.s"
.include "assets/sprites.h.s"
.include "sys/ai_control.h.s"

.include "cpctelera.h.s"

.module sys_ai_control

DefineEntity bullet_enemy, 60, 20, 4, 10, 0, 0, 0xF0, coll_type_enemy_bullet, 1, 0x0000, #e_ai_st_noAI, _sp_balaEnemigo, 0x0000, 0x0000, action_enemy_patrol
DefineEntity bullet_enemy_2, 60, 20, 4, 10, 0, 0, 0xF0, coll_type_enemy_bullet, 1, 0x0000, #e_ai_st_noAI, _sp_balaEnemigo, 0x0000, 0x0000, action_enemy_patrol
DefineEntity bullet_enemy_3, 60, 20, 4, 10, 0, 0, 0xF0, coll_type_enemy_bullet, 1, 0x0000, #e_ai_st_noAI, _sp_balaEnemigo, 0x0000, 0x0000, action_enemy_patrol

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  SYS AI CONTROL::Init
;;      Updates all AI entities
;;
;;  INPUT:
;;      IX: Pointer to entity array
;;
sys_ai_control_init::
    	ld (_ent_array_ptr), ix     ;;[6]
    	ret

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  SYS AI CONTROL::update
;;      Updates all AI entities
;;
;;  INPUT:
;;      IX: Pointer to entity array
;;      A: Number of elements in the array
;;  DESTROYS: AF, DE, IX
;;  STACK USE: 2 bytes
sys_ai_control_update::
	ld	(_ent_counter), a

_ent_array_ptr = . + 2
    	ld  	ix, #0x0000     ;;[4]
_loop:

	ld	a, e_ai_st(ix)
	cp	#e_ai_st_noAI
	jr 	z, _no_AI_ent

_AI_ent:
	cp	#e_ai_st_stand_by
	call	z, sys_ai_stand_by
	cp	#e_ai_st_to_player
	call	z, sys_ai_to_player
	cp	#e_ai_st_move_to
	call	z, sys_ai_move_to
	cp	#e_ai_st_patrol
	call	z, sys_ai_patrol

	;; this can be replace with puntero to the function
_no_AI_ent:

_ent_counter = . + 1
	ld 	a, #0
	dec 	a
	ret 	z

	ld	(_ent_counter), a
	;; Jump to next entity
    	ld  	de, #sizeof_e 
    	add  	ix, de

    	jr	_loop

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  SYS AI CONTROL::stand_by
;;	INPUT: IX: pointer entity
;;	Charge the patrol patron and change de state
;;      
sys_ai_stand_by::
    	call man_patrol_get	;;hl - patrol01
    	ld e_ai_patrol_step_l(ix), l ;;apunto al primer paso que tengo que dar
    	ld e_ai_patrol_step_h(ix), h
    	ld e_ai_pre_st(ix), #e_ai_st_stand_by
    	ld e_ai_st(ix), #e_ai_st_patrol

    	ret

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  SYS AI CONTROL::move_to
;;	INPUT: 	IX entity to move
;;	
;;  DESTROYS: AF
;;      
sys_ai_move_to::
	ld	e_vx(ix), #0

	;; UPDATE X
	ld	a, e_ai_aim_x(ix)			;; A = obj_x
	sub 	e_x(ix)				;; A = obj_x -x
	jr	nc, _objx_greater_or_equal	;; if (obj_x -x > 0) objx_
_objx_lesser:
	ld 	e_vx(ix), #-1
	jr	_endif_x	
_objx_greater_or_equal:
	jr	z, _arrived_x
	cp #01
	jp 	z, _arrived_x
	ld 	e_vx(ix), #1
	jr	_endif_x		
_arrived_x:
	ld 	e_vx(ix), #0
_endif_x:

	;; UPDATE Y
	ld	a, e_ai_aim_y(ix)			;; A = obj_y
	sub 	e_y(ix)				;; A = obj_x -x
	jr	nc, _objy_greater_or_equal	;; if (obj_x -x > 0) objx_
_objy_lesser:
	ld 	e_vy(ix), #-2
	jr	_endif_y	
_objy_greater_or_equal:
	jr	z, _arrived_y
	cp #01
	jp 	z, _arrived_y
	ld 	e_vy(ix), #2
	jr	_endif_y		
_arrived_y:
	ld 	e_vy(ix), #0
	ld	a, e_vx(ix)
	or	a
	jr	nz, _endif_y
		;; X and Y are both 0
		ld	a, e_ai_pre_st(ix)
		ld	e_ai_st(ix), a ;;
		ld	e_ai_pre_st(ix), #e_ai_st_patrol
_endif_y:

	ret



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  SYS AI CONTROL::patrol
;;      Updates all AI entities
;;
;;  INPUT:
;;      IX: Pointer to entity array
;;  DESTROYS: AF, BC, IY, HL
sys_ai_patrol::
	;; 	Set the patrol to player
	;; HL Points to next(X,Y) AI control step
	ld	l, e_ai_patrol_step_l(ix)
	ld	h, e_ai_patrol_step_h(ix)

	;; COMPROBAR X!=-1
	ld	a, (hl) 	;;A = x
	cp	#patrol_invalid_move_x
	jr	z, _reset_patrol

	;; Set AI-AIM(X,Y)
	ld 	e_ai_aim_x(ix), a
	inc 	hl		;; Point to y
	ld	a, (hl)	;;A = x
	ld 	e_ai_aim_y(ix), a

	;;SET e_ai_patrol_step + 2
	inc 	hl
	ld	e_ai_patrol_step_l(ix), l
	ld	e_ai_patrol_step_h(ix), h

	;; CHANGE TO move_to
	ld 	e_ai_pre_st(ix), #e_ai_st_patrol
	ld 	e_ai_st(ix), #e_ai_st_move_to
	
	ld	a, e_enemy_action(ix)
	cp	#action_enemy_shoot
	call 	z, sys_ai_shoot	
	ret

_reset_patrol:
	;; GET Next 2 Bytes pointes b HL, which
	;; Point to the start of the patrol
	inc 	hl
 	ld	c, (hl)
 	inc	hl
 	ld	b, (hl)
 	ld 	h, b
 	ld	l, c

	push ix
	push hl
	call entityman_getEntityArray
	;; pos player
	ld a, e_x(ix)	
	ld (hl), a
	inc hl
	ld a, e_y(ix)
	ld (hl), a
	pop hl
	pop ix

	;; Reset patrol step
	ld	e_ai_patrol_step_l(ix), l
	ld	e_ai_patrol_step_h(ix), h
	ret

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  SYS AI CONTROL::shoot
;;      Create 3 entities bullet
;;
;;  INPUT:
;;      IX: Pointer to entity
;;  DESTROYS: DE, IY, HL
sys_ai_shoot::
	;;Get position enemy
	ld d, e_x(ix)       
    	ld e, e_y(ix) 

    	;; bullet go down-right
    	ld iy, #bullet_enemy                          	;;Get bullet entity in IY
    	call _set_bullet_position
    	ld e_vx(iy), #1
    	ld e_vy(iy), #2
    	;Add bullet to entity array
    	push de
    	ld hl, #bullet_enemy
    	call entityman_create
    	pop de

    	;; bullet got down-left
    	ld iy, #bullet_enemy_2                          	;;Get bullet entity in IY
    	call _set_bullet_position
    	ld e_vx(iy), #-1
    	ld e_vy(iy), #2
    	push de
    	ld hl, #bullet_enemy_2
    	call entityman_create
    	pop de

    	;; bullet go straight
    	ld iy, #bullet_enemy_3                        	;;Get bullet entity in IY
    	call _set_bullet_position
    	ld e_vx(iy), #0
    	ld e_vy(iy), #2
    	push de
    	ld hl, #bullet_enemy_3
    	call entityman_create
    	pop de

    	ret

_set_bullet_position:
	ld e_x(iy), d
	ld e_y(iy), e

    	ret

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  SYS AI CONTROL::TO_PLAYER
;;      Create 3 entities bullet
;;
;;  INPUT:
;;      IX: Pointer to entity
;;  DESTROYS: BC, HL
sys_ai_to_player::
	;;Enemy pointer
	ld__d_ixh
	ld__e_ixl

 	call entityman_getEntityArray           	;;Get entity array on IX
	;;Get player positions
	ld b, e_x(ix)
	ld c,	e_y(ix)
	ld hl, #0060	
	add hl, bc		;; add 60 to position e_y

	ld b, h
	ld c, l

	;; charge enemy pointer
	ld__ixh_d
	ld__ixl_e
	;; set objective enemy
	ld e_ai_aim_x(ix), b
	ld e_ai_aim_y(ix), c

	ld e_ai_st(ix), #e_ai_st_move_to 

	ret
