;;-----------------------------LICENSE NOTICE------------------------------------
;; This file is part of Invasion a Marte: An Amstrad CPC Game 
;; Copyright (C) 2019 
;; Authors:
;;  * Antonio Macia Lillo       tonetml23@gmail.com
;;  * Gina Esthela Abad Jimenez abadjimenezgina@gmail.com
;;  * Ivan Martinez Molina      imm79@alu.ua.es
;;
;;  This program is free software: you can redistribute it and/or modify
;;  it under the terms of the GNU Lesser General Public License as published by
;;  the Free Software Foundation, either version 3 of the License, or
;;  (at your option) any later version.
;;
;;  This program is distributed in the hope that it will be useful,
;;  but WITHOUT ANY WARRANTY; without even the implied warranty of
;;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;  GNU Lesser General Public License for more details.
;;
;;  You should have received a copy of the GNU Lesser General Public License
;;  along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;-------------------------------------------------------------------------------

.include "cpctelera.h.s"
.include "cpctelera_functions.h.s"
.include "sys/render_system.h.s"
.include "man/entity_manager.h.s"
.include "sys/input_system.h.s"
.include "man/player_manager.h.s"


key_c_pressed:: .db 0

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Inits input system
;;
;;INPUT:
;;DESTROYS:
;;
sys_input_init::
    ret


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Gets keyboard inputs and aplies them to
;; keyboard controlled entities.
;; DANGER: assumes entity 0 always exists
;;
;;INPUT:
;; IX = Pointer to entity[0]
;;DESTROYS: DE, HL, BC, AF, IX
;;
sys_input_update::
    ;;reset velocities
    ld e_vx(ix), #0
    ld e_vy(ix), #0

    ;; Scan the keyboard
    ;call cpct_scanKeyboard_f_asm

    ;; Check for movement keys
    ld hl, #Key_O                   ;; hl holds key code to check
    call cpct_isKeyPressed_asm      ;;
    jr z, O_NotPressed              ;; If Key_0 is pressed then
O_Pressed:
    ld e_vx(ix), #player_negative_speed_x;; Set speed to -1
O_NotPressed:


    ld hl, #Key_P                   ;; hl holds key code to check
    call cpct_isKeyPressed_asm      ;;
    jr z, P_NotPressed              ;; If Key_P is pressed then
P_Pressed:
    ld e_vx(ix), #player_speed_x    ;; Set speed to -1
P_NotPressed:


    ld hl, #Key_Q                   ;; hl holds key code to check
    call cpct_isKeyPressed_asm      ;;
    jr z, Q_NotPressed              ;; If Key_Q is pressed then
Q_Pressed:
    ld e_vy(ix), #player_negative_speed_y;; Set speed to -1
Q_NotPressed:


    ld hl, #Key_A                   ;; hl holds key code to check
    call cpct_isKeyPressed_asm      ;;
    jr z, A_NotPressed              ;; If Key_0 is pressed then
A_Pressed:
    ld e_vy(ix), #player_speed_y    ;; Set speed to -1
A_NotPressed:

    ;; Check for movement keys
    ld hl, #Key_S                   ;; hl holds key code to check
    call cpct_isKeyPressed_asm      ;;
    jr z, S_NotPressed              ;; If Key_0 is pressed then
S_Pressed:
    ld e_vx(ix), #player_negative_speed_x;; Set speed to -1
S_NotPressed:


    ld hl, #Key_F                   ;; hl holds key code to check
    call cpct_isKeyPressed_asm      ;;
    jr z, F_NotPressed              ;; If Key_P is pressed then
F_Pressed:
    ld e_vx(ix), #player_speed_x    ;; Set speed to -1
F_NotPressed:


    ld hl, #Key_E                   ;; hl holds key code to check
    call cpct_isKeyPressed_asm      ;;
    jr z, E_NotPressed              ;; If Key_Q is pressed then
E_Pressed:
    ld e_vy(ix), #player_negative_speed_y;; Set speed to -1
E_NotPressed:


    ld hl, #Key_D                   ;; hl holds key code to check
    call cpct_isKeyPressed_asm      ;;
    jr z, D_NotPressed              ;; If Key_0 is pressed then
D_Pressed:
    ld e_vy(ix), #player_speed_y    ;; Set speed to -1
D_NotPressed:

    ld hl, #Key_Return                   ;; hl holds key code to check
    xor a                           ;; a = 0
    ld (key_c_pressed), a 
    call cpct_isKeyPressed_asm      ;;
    jr z, Return_NotPressed              ;; If Key_0 is pressed then
Return_Pressed:
    ld a, #1
    ld (key_c_pressed), a                ;; Set memory position to 1
Return_NotPressed:

    ld hl, #Key_Space                  ;; hl holds key code to check
    call cpct_isKeyPressed_asm      ;;
    jr z, Space_NotPressed              ;; If Key_0 is pressed then
Space_Pressed:
    call man_player_shoot_forward
Space_NotPressed:

    ld hl, #Key_X                ;; hl holds key code to check
    call cpct_isKeyPressed_asm      ;;
    jr z, X_NotPressed              ;; If Key_0 is pressed then
X_Pressed:
    call man_player_shoot_left
X_NotPressed:

    ld hl, #Key_M                  ;; hl holds key code to check
    call cpct_isKeyPressed_asm      ;;
    jr z, M_NotPressed              ;; If Key_0 is pressed then
M_Pressed:
    call man_player_shoot_right
M_NotPressed:


    ld hl, #Key_K                  ;; hl holds key code to check
    call cpct_isKeyPressed_asm      ;;
    jr z, K_NotPressed              ;; If Key_0 is pressed then
K_Pressed:
    call man_player_shoot_forward
K_NotPressed:

    ld hl, #Key_J                  ;; hl holds key code to check
    call cpct_isKeyPressed_asm      ;;
    jr z, J_NotPressed              ;; If Key_0 is pressed then
J_Pressed:
    call man_player_shoot_left
J_NotPressed:

        ld hl, #Key_L                  ;; hl holds key code to check
    call cpct_isKeyPressed_asm      ;;
    jr z, L_NotPressed              ;; If Key_0 is pressed then
L_Pressed:
    call man_player_shoot_right
L_NotPressed:

ret

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Gets keyboard inputs and aplies them to
;; keyboard controlled entities.
;; DANGER: assumes entity 0 always exists
;;
;;INPUT:
;; IX = Pointer to entity[0]
;;DESTROYS: DE, HL, BC, AF, IX
;;RETURNS
;; A -> 0 IF NOT PRESSED, 1 IF PRESSED
;;
; is_c_down::
;     ld a, (key_c_pressed)
;     ret