;;-----------------------------LICENSE NOTICE------------------------------------
;; This file is part of Invasion a Marte: An Amstrad CPC Game 
;; Copyright (C) 2019 
;; Authors:
;;  * Antonio Macia Lillo       tonetml23@gmail.com
;;  * Gina Esthela Abad Jimenez abadjimenezgina@gmail.com
;;  * Ivan Martinez Molina      imm79@alu.ua.es
;;
;;  This program is free software: you can redistribute it and/or modify
;;  it under the terms of the GNU Lesser General Public License as published by
;;  the Free Software Foundation, either version 3 of the License, or
;;  (at your option) any later version.
;;
;;  This program is distributed in the hope that it will be useful,
;;  but WITHOUT ANY WARRANTY; without even the implied warranty of
;;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;  GNU Lesser General Public License for more details.
;;
;;  You should have received a copy of the GNU Lesser General Public License
;;  along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;-------------------------------------------------------------------------------

;;
;; ENTITY PHYSICS MOVEMENTS
;;      Moves the entities acording to its velocity
;;

.include "man/entity_manager.h.s"
.include "cpctelera.h.s"
.include "man/animation_manager.h.s"

.module sys_entity_physics

screen_width = 80
screen_height = 200

;;
;; Inits the render system
;;
physics_init::
    ret


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Updates all physics components of entities
;; Assumes all entities are contigous
;; Assumes there is at least one entity in the array
;;
;;INPUT:
;; IX: Pointer to entity array
;; A: Number of elements in the array
;;DESTROYS: AF, DE, BC, IX
;;
physics_update::
_move_loop:
    ;; UPDATE X
    push af             ;; Save number of entities in the stack
    ld a, e_next_anim_h(ix)         ;; Check if doesn't have animation
    or a
    jp z, _ignore
    call physics_checkdir           ;; Check if animation has changed acording to its direction
_ignore:

    ld a, #screen_width + 1
    sub e_w(ix) ;;screen width - entity_widht = max valid position without exiting screen
    ld c, a

    ld a, e_x(ix)
    add e_vx(ix)        ;; position + speed
    cp c                ;; newposition <= max_valid_position?. 
    jr nc, invalid_x    ;; then dont jump
valid_x:
    ld e_x(ix), a
    jr endif_x
invalid_x:  ;;Do not change x
    ld a, e_collider(ix);; Load collision type onto a
    cp a, #coll_type_player
    jp nz, _entity_out_scr

endif_x:

    ;;UPDATE Y
    ld a, #screen_height + 1
    sub e_h(ix) ;;screen width - entity_widht = max valid position without exiting screen
    ld c, a

    ld a, e_y(ix)
    add e_vy(ix)        ;; position + speed
    cp c                ;; newposition <= max_valid_position?. 
    jr nc, invalid_y    ;; then dont jump
valid_y:
    ld e_y(ix), a
    jr endif_y
invalid_y: ;;Do not chage y
    ld a, e_collider(ix);; Load collision type onto a
    cp a, #coll_type_player
    jp nz, _entity_out_scr
endif_y:
    ld bc, #sizeof_e    ;; Load in bc the size of an entity
    add ix, bc          ;; Make pointer point to the next entity by adding the size of an entity
_dont_inc_counter:
    pop af              ;; Pop entity counter
    dec a               ;; a--
    jp nz, _move_loop   ;; if a = 0 -> mover la siguiente entidad
    ret

;;When a bullet runs out of the screen destroy it
_entity_out_scr:
    ld__d_ixh
    ld__e_ixl  
    push ix                     ;; Load pointer to entity on de
    call entityman_deletearr_add    ;; Add it to the delete array
    pop ix
    jp endif_y



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Checks if the direction of the entity changed
;;
;;INPUT:
;; IX: Pointer to entity
;;DESTROYS: AF, DE, BC, HL
;;
physics_checkdir::
    ;;Check x state
    ld a, e_vx(ix)
    ld b, e_last_vx(ix)
    xor b                           ;; Xor wil put a to 0 if didn't changed
    jp z, _x_not_changed
    call man_animation_change
    jp _record_speed

_x_not_changed:
    ;;Check y state
    ld a, e_vy(ix)
    ld b, e_last_vy(ix)
    xor b                           ;; Xor wil put a to 0 if didn't changed
    jp z, _record_speed
    call man_animation_change

_record_speed:
    ld a, e_vx(ix)
    ld e_last_vx(ix), a
    ld a, e_vy(ix)
    ld e_last_vy(ix), a
    ret

    