;;-----------------------------LICENSE NOTICE------------------------------------
;; This file is part of Invasion a Marte: An Amstrad CPC Game 
;; Copyright (C) 2019 
;; Authors:
;;  * Antonio Macia Lillo       tonetml23@gmail.com
;;  * Gina Esthela Abad Jimenez abadjimenezgina@gmail.com
;;  * Ivan Martinez Molina      imm79@alu.ua.es
;;
;;  This program is free software: you can redistribute it and/or modify
;;  it under the terms of the GNU Lesser General Public License as published by
;;  the Free Software Foundation, either version 3 of the License, or
;;  (at your option) any later version.
;;
;;  This program is distributed in the hope that it will be useful,
;;  but WITHOUT ANY WARRANTY; without even the implied warranty of
;;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;  GNU Lesser General Public License for more details.
;;
;;  You should have received a copy of the GNU Lesser General Public License
;;  along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;-------------------------------------------------------------------------------


.include "cpctelera_functions.h.s"
.include "cpctelera.h.s"
.include "sys/render_system.h.s"
.include "man/entity_manager.h.s"
.include "man/player_manager.h.s"
.include "assets/sprites.h.s"
.include "man/game_manager.h.s"

.module render_system

rendersys_init::
    ld hl, #_pal_main
    ;ld hl, #_paleta
    ld de, (palette_size)
    call cpct_setPalette_asm
    cpctm_setBorder_asm HW_BLUE

    ;;Set lifes sprite
    ld hl, #_sp_elemento_15
    ld (life1), hl
    ld (life2), hl
    ld (life3), hl

    call rendersys_refreshscr
    ret

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Renders all game entities
;;
;;INPUT:
;; IX: Pointer to the first entity to render
;; A: Number of entities to render
;; DESTROYS: AF, IX, DE, HL, BC
;;
rendersys_update::
    ;; Render Entities
    cp #1                                       ;; Check if a is 0
    jp z, _render_player                        ;; Then just render the player

    push ix
    ld bc, #sizeof_e
    add ix, bc
    dec a
    call rendersys_render_entities              ;; Draw entities
    pop ix

_render_player:
;     ld a, e_checkcoll(ix)
;     or a                                        ;; If player took a hit, e_checkcoll will alternate
    ld a, #1                                    ;; between 0 and 1, dont draw player if its 0
    call rendersys_render_entities

    call rendersys_drawintfc                    ;; Draw interface
    ret


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Draws the entity in background color to erase it
;;
;;INPUT:
;; IX: Pointer to the entity to render
;; DESTROYS: AF, IX, BC
;; RETURNS:
;;   BC: Height and width of the entity
rendersys_draw_sprite_background::
    ;;Erase previous instance (Draw background pixels)
    ld e, e_lastVP_l(ix)
    ld d, e_lastVP_h(ix)
    ld a, (background_color)
    ld c, e_w(ix)
    ld b, e_h(ix)
    push bc
    call cpct_drawSolidBox_asm
    pop bc
    ret


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Renders all entities of the entity array
;; Assumes all entities are contiguous
;; Assumes there is at least one entity to render
;;
;;INPUT:
;; IX: Pointer to the first entity to render
;; A: Number of entities to render
;; DESTROYS: AF, IX, DE, HL, BC
;;
rendersys_render_entities::
ld (_ent_counter), a              ;;Save entity counter

_renderloop:
    ld c, e_w(ix)
    ld b, e_h(ix)

    ld a, e_collider(ix)
    xor #coll_type_nocoll                                  ;;Make a = 0 if type is buyllet
    call nz, rendersys_draw_sprite_background                ;; Only erase the bullets
    push bc ;; este puede que sobre porque ya esta en la funcion de arriba

    ;; Calculate a video-memory location for printing a sprite
    ld   de, #screen_start ;; DE = Pointer to start of the screen
    ld    c, e_x(ix)                  ;; C = x coordinate (16 = 0x10)
    ld    b, e_y(ix)                  ;; B = y coordinate (24 = 0x18)
    call cpct_getScreenPtr_asm    ;; Calculate video memory location and return it in HL

    ;; Store Video Memory Pointer as Last
    ld e_lastVP_l(ix), l
    ld e_lastVP_h(ix), h

    ;; draw entity sprite
    ex de, hl
    ld l, e_pspr_l(ix)             
    ld h, e_pspr_h(ix)
    pop bc                      ;; extract width and heigh from the stack
    call cpct_drawSprite_asm


_ent_counter = .+1              ;;
    ld a, #0                    ;; A: Number of elements left
    dec a                       ;; Entities--
    ret z

    ld (_ent_counter), a        ;; Update entity counter
    ld bc, #sizeof_e
    add ix, bc                  ;; make pointer point to the next entity
    jr _renderloop

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Displays the game over screen
;;
;;INPUT:
;; IX: Pointer to the first entity to render
;; A: Number of entities to render
;; DESTROYS: AF, DE, HL, BC
;;
rendersys_gameoverscr::
    ;;Load background and foreground colors
    ld a, (foreground_color)
    ld l, a
    ld a, (background_color)
    ld h, a
    call cpct_setDrawCharM0_asm         ;; Set them


    ;;dibuja la pantalla de game over
    call rendersys_dibujarPlaneta
    call rendersys_textoGameOver
    call rendersys_dibujarFondoGameOver

    ret

;;;;;;;;;;;;;;;;;;;;;;;;;;;;
rendersys_textoGameOver::
    ld de, #screen_start
    ld    a, #0x12
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_enemyDoble_14
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x1A
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_enemyDoble_15
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x22
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_enemyDoble_16
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x2A
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_enemyDoble_20
    ld bc, #0x1008
    call cpct_drawSprite_asm



    ld de, #screen_start
    ld    a, #0x32
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_enemyDoble_21
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x3A
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_enemyDoble_22
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ret



rendersys_dibujarPlaneta::
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;PLANETA
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x78 ;120
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_portadaPlaneta_0
    ld bc, #0x5028
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x78
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_portadaPlaneta_1
    ld bc, #0x5028
    call cpct_drawSprite_asm

    ret

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
rendersys_dibujarBandera::
     ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x20
    ld c, a
    ld    a, #0x74
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_enemyDoble_18
    ld bc, #0x1008
    call cpct_drawSprite_asm


     ld de, #screen_start
    ld    a, #0x20
    ld c, a
    ld    a, #0x64
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_enemyDoble_12
    ld bc, #0x1008
    call cpct_drawSprite_asm


     ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x64
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_enemyDoble_13
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ret

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
rendersys_textoPortada::
    ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_portadaTexto1_0
    ld bc, #0x2010
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL
    
    ex de, hl
    ld hl, #_sp_portadaTexto1_1
    ld bc, #0x2010
    call cpct_drawSprite_asm

   

    ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_portadaTexto1_2
    ld bc, #0x2010
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_portadaTexto1_3
    ld bc, #0x2010
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;FIN TEXTO INVASION
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
     ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_portadaTexto2_0
    ld bc, #0x2010
    call cpct_drawSprite_asm

      ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_portadaTexto2_1
    ld bc, #0x2010
    call cpct_drawSprite_asm

      ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_portadaTexto2_2
    ld bc, #0x2010
    call cpct_drawSprite_asm

      ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_portadaTexto2_3
    ld bc, #0x2010
    call cpct_drawSprite_asm

    ret


rendersys_textoEnter::
  
    ld de, #screen_start
    ld    a, #0x12
    ld c, a
    ld    a, #0x68
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento_01
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;
     ld de, #screen_start
    ld    a, #0x1A
    ld c, a
    ld    a, #0x68
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento_02
    ld bc, #0x1008
    call cpct_drawSprite_asm
    
    ;;;;;;;;;;;;;;;;;;;;;;
     ld de, #screen_start
    ld    a, #0x22
    ld c, a
    ld    a, #0x68
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
   
    ;;;;;;;;;;;;;;;;;;;;;;
     ld de, #screen_start
    ld    a, #0x2A
    ld c, a
    ld    a, #0x68
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento_06
    ld bc, #0x1008
    call cpct_drawSprite_asm
    
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x32
    ld c, a
    ld    a, #0x68
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento_07
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ret

rendersys_dibujarFondoGameOver::
    ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x10
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL


    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x20
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x30
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x40
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x10
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL


    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x20
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x30
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x40
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;

    ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x10
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL


    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x20
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x30
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x40
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x10
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL


    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x20
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x30
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x40
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x10
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL


    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x20
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x30
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x40
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

    ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x10
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL


    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x20
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x30
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x40
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x10
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL


    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x20
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x30
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x40
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


   ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x0A
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x40
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm



    ret



rendersys_dibujarFondoGanar::
    ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x10
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL


    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x20
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x30
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x40
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
      ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x10
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL


    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x20
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x30
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x40
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;
      ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x10
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL


    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x20
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x30
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x40
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
      ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x10
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL


    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x20
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x30
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x40
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
      ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

       ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;

       ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x10
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL


    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x20
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x30
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x40
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;

       ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x10
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL
    

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x20
    ld c, a
    ld    a, #0x54
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm



    ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x56
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL


    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm



    ld de, #screen_start
    ld    a, #0x30
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x40
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

       ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x10
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


     ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x74
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x30
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x40
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ret







rendersys_dibujarFondo::
    ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x00
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;

     ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x10
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;


     ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x20
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
     ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x30
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
     ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
     ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
     ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x60
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x00
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x48
    ld c, a
    ld    a, #0x70
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;

     ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;

     ld de, #screen_start
    ld    a, #0x0f
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;
    
     ld de, #screen_start
    ld    a, #0x17
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;

     ld de, #screen_start
    ld    a, #0x1e
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x25
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;

    
     ld de, #screen_start
    ld    a, #0x2d
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;
    
     ld de, #screen_start
    ld    a, #0x35
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;
    
     ld de, #screen_start
    ld    a, #0x3d
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;
    
     ld de, #screen_start
    ld    a, #0x44
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;

     ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;

     ld de, #screen_start
    ld    a, #0x0f
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;
    
     ld de, #screen_start
    ld    a, #0x17
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;

     ld de, #screen_start
    ld    a, #0x1e
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x25
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;

    
     ld de, #screen_start
    ld    a, #0x2d
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;
    
     ld de, #screen_start
    ld    a, #0x35
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;
    
     ld de, #screen_start
    ld    a, #0x3d
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;
    
     ld de, #screen_start
    ld    a, #0x44
    ld c, a
    ld    a, #0x50
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;

     ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x58
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;

     ld de, #screen_start
    ld    a, #0x0f
    ld c, a
    ld    a, #0x58
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;
    
     ld de, #screen_start
    ld    a, #0x17
    ld c, a
    ld    a, #0x58
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;

     ld de, #screen_start
    ld    a, #0x1e
    ld c, a
    ld    a, #0x58
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x25
    ld c, a
    ld    a, #0x58
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;

    
     ld de, #screen_start
    ld    a, #0x2d
    ld c, a
    ld    a, #0x58
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;
    
     ld de, #screen_start
    ld    a, #0x35
    ld c, a
    ld    a, #0x58
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;
    
     ld de, #screen_start
    ld    a, #0x3d
    ld c, a
    ld    a, #0x58
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
      ;;;;;;;;;;;;;;;;;;;;;;;;;;
    
     ld de, #screen_start
    ld    a, #0x44
    ld c, a
    ld    a, #0x58
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;


     ld de, #screen_start
    ld    a, #0x04
    ld c, a
    ld    a, #0x68
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x0B
    ld c, a
    ld    a, #0x68
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    ;;;;;;;;;;;;;;;;;;;;;;;;;;

     ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x3A
    ld c, a
    ld    a, #0x68
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm
    
    ;;;;;;;;;;;;;;;;;;;;;;;;;;

     ;;;;;;;;;;;;;;;;;;;;;;;;;;
    ld de, #screen_start
    ld    a, #0x42
    ld c, a
    ld    a, #0x68
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_03
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ret
    ;;;;;;;;;;;;;;;;;;;;;;;;;;
    

rendersys_textoHasGanado::
     ld de, #screen_start
    ld    a, #0x08
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_00
    ld bc, #0x1008
    call cpct_drawSprite_asm

     ld de, #screen_start
    ld    a, #0x10
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_01
    ld bc, #0x1008
    call cpct_drawSprite_asm

      ld de, #screen_start
    ld    a, #0x18
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_02
    ld bc, #0x1008
    call cpct_drawSprite_asm

    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
     ld de, #screen_start
    ld    a, #0x20
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_04
    ld bc, #0x1008
    call cpct_drawSprite_asm

     ld de, #screen_start
    ld    a, #0x28
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_05
    ld bc, #0x1008
    call cpct_drawSprite_asm

      ld de, #screen_start
    ld    a, #0x30
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_06
    ld bc, #0x1008
    call cpct_drawSprite_asm

       ld de, #screen_start
    ld    a, #0x38
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_07
    ld bc, #0x1008
    call cpct_drawSprite_asm


    ld de, #screen_start
    ld    a, #0x40
    ld c, a
    ld    a, #0x40
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, #_sp_elemento2_13
    ld bc, #0x1008
    call cpct_drawSprite_asm


  ret

rendersys_dibujarPantallaFin::
    call rendersys_dibujarPlaneta
    call rendersys_dibujarBandera
    call rendersys_textoHasGanado
    call rendersys_dibujarFondoGanar
    ret

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Displays the game over screen
;;
;;INPUT:
;; IX: Pointer to the first entity to render
;; A: Number of entities to render
;; DESTROYS: AF, DE, HL, BC
;;
rendersys_startscr::
    ;;Load background and foreground colors
    ld a, (foreground_color)
    ld l, a
    ld a, (background_color)
    ld h, a
    call cpct_setDrawCharM0_asm         ;; Set them

 
    call rendersys_dibujarPlaneta
    call rendersys_textoPortada
    call rendersys_textoEnter
    call rendersys_dibujarFondo
    ret
    
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Crears all the screen. CAUTION: very low speed
;;
;;INPUT: -
;;DESTROYS: AF, BC, DE, HL
rendersys_refreshscr::
    ld bc, #0xfa40                        ;; full width and eh
    ld de, #0xc010                        ;; load memory video pointer to video memory start
    ld a, (background_color)             ;; background color
    call cpct_drawSolidBox_asm

    ld bc, #0xfa40                        ;; full width and eh
    ld de, #0xc000                        ;; load memory video pointer to video memory start
    ld a, (background_color)             ;; background color
    call cpct_drawSolidBox_asm
    ret

life1:: .dw #_sp_elemento_15
life2:: .dw #_sp_elemento_15
life3:: .dw #_sp_elemento_15

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;DESCRIPTION
;; Draws the interface
;;start_string_y
;;INPUT: -
;;DESTROYS: AF, BC, DE, HL, IX, IY
rendersys_drawintfc::
    ;; Update heatlh value
;     call man_player_getdata                 ;; Gets health value on a
;     ld iy, #health_string                   ;; Load health string on ix
;     ld a, #0x30                             ;; Start of ascii numbers
;     add b                                   ;; 30 + health will be the correct character number (Ej: 1 -> 31)
;     ld health_value_pos(iy), a              ;; Load health value to the string

;     ;;Calculate memory possition
;     ld   de, #screen_start                  ;; DE = Pointer to start of the screen
;     ld    a, #health_string_x              ;; C = x coordinate (16 = 0x10)
;     ld c, a
;     ld    a, #health_string_y
;     ld b, a                                 ;; B = y coordinate (24 = 0x18)
;     call cpct_getScreenPtr_asm              ;; Calculate video memory location and return it in HL

;     ;;Draw health string
;     call cpct_drawStringM0_asm

    ld de, #screen_start
    ld    a, #health_string_x
    ld c, a
    ld    a, #health_string_y
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, (life1)
    ld bc, #0x1008 ;;80x100  b =28 (40 en dec) c = 64 (100 en dec)  

    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #health_string_x + 8
    ld c, a
    ld    a, #health_string_y
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, (life2)
    ld bc, #0x1008 ;;80x100  b =28 (40 en dec) c = 64 (100 en dec)  
    
    call cpct_drawSprite_asm

    ld de, #screen_start
    ld    a, #health_string_x + 16
    ld c, a
    ld    a, #health_string_y
    ld    b, a
    call cpct_getScreenPtr_asm          ;; Calculate video memory location and return it in HL

    ex de, hl
    ld hl, (life3)
    ld bc, #0x1008 ;;80x100  b =28 (40 en dec) c = 64 (100 en dec)  

    
    call cpct_drawSprite_asm
    ret